@@ -37,6 +37,10 @@ SvgItem::SvgItem(QQuickItem *parent)
 
 SvgItem::~SvgItem()
 {
+    // Make sure to not call anything on m_svg when this is shutting down
+    // Kirigami::PlatformTheme will lose its window at that point so will
+    // emit colorschanged, which we shouldn't react to during destructor
+    disconnect(m_kirigamiTheme, nullptr, this, nullptr);
 }
 
 void SvgItem::componentComplete()
@@ -60,13 +64,15 @@ void SvgItem::componentComplete()
             m_svg->clearColorOverrides();
             return;
         }
-        m_svg->setColor(Svg::Text, m_kirigamiTheme->textColor());
-        m_svg->setColor(Svg::Background, m_kirigamiTheme->backgroundColor());
-        m_svg->setColor(Svg::Highlight, m_kirigamiTheme->highlightColor());
-        m_svg->setColor(Svg::HighlightedText, m_kirigamiTheme->highlightedTextColor());
-        m_svg->setColor(Svg::PositiveText, m_kirigamiTheme->positiveTextColor());
-        m_svg->setColor(Svg::NeutralText, m_kirigamiTheme->neutralTextColor());
-        m_svg->setColor(Svg::NegativeText, m_kirigamiTheme->negativeTextColor());
+        m_svg->setColors({
+            {Svg::Text, m_kirigamiTheme->textColor()},
+            {Svg::Background, m_kirigamiTheme->backgroundColor()},
+            {Svg::Highlight, m_kirigamiTheme->highlightColor()},
+            {Svg::HighlightedText, m_kirigamiTheme->highlightedTextColor()},
+            {Svg::PositiveText, m_kirigamiTheme->positiveTextColor()},
+            {Svg::NeutralText, m_kirigamiTheme->neutralTextColor()},
+            {Svg::NegativeText, m_kirigamiTheme->negativeTextColor()},
+        });
     };
     applyTheme();
     connect(m_kirigamiTheme, &Kirigami::Platform::PlatformTheme::colorsChanged, this, applyTheme);
